@@ -49,7 +49,9 @@ class DomaPanDAWork(Work):
                  task_log=None,
                  task_cloud=None,
                  task_site=None,
-                 task_rss=1000):
+                 task_rss=1000,
+                 vo='wlcg',
+                 working_group='lsst'):
 
         super(DomaPanDAWork, self).__init__(executable=executable, arguments=arguments,
                                             parameters=parameters, setup=setup, work_type=TransformType.Processing,
@@ -78,7 +80,7 @@ class DomaPanDAWork(Work):
         self.task_name = task_name
         self.real_task_name = None
         self.set_work_name(task_name)
-        self.queue = task_queue
+        self.task_queue = task_queue
         self.dep_tasks_id_names_map = {}
         self.executable = executable
         self.processingType = processing_type
@@ -94,6 +96,9 @@ class DomaPanDAWork(Work):
         self.task_site = task_site
         self.task_rss = task_rss
 
+        self.vo = vo
+        self.working_group = working_group
+
         self.retry_number = 0
         self.num_retries = num_retries
 
@@ -101,6 +106,8 @@ class DomaPanDAWork(Work):
 
         self.load_panda_urls()
 
+        self.dependency_tasks = None
+
     def my_condition(self):
         if self.is_finished():
             return True
@@ -180,14 +187,24 @@ class DomaPanDAWork(Work):
             self.poll_panda_jobs_chunk_size = int(self.agent_attributes['poll_panda_jobs_chunk_size'])
 
     def depend_on(self, work):
-        for job in self.dependency_map:
-            inputs_dependency = job["dependencies"]
+        self.logger.debug("checking depending on")
+        if self.dependency_tasks is None:
+            self.logger.debug("constructing dependency_tasks set")
+            dependency_tasks = set([])
+            for job in self.dependency_map:
+                inputs_dependency = job["dependencies"]
 
-            for input_d in inputs_dependency:
-                task_name = input_d['task']
-                if task_name == work.task_name:
-                    return True
-        return False
+                for input_d in inputs_dependency:
+                    task_name = input_d['task']
+                    dependency_tasks.add(task_name)
+            self.dependency_tasks = list(dependency_tasks)
+
+        if work.task_name in self.dependency_tasks:
+            self.logger.debug("finished checking depending on")
+            return True
+        else:
+            self.logger.debug("finished checking depending on")
+            return False
 
     def get_ancestry_works(self):
         tasks = set([])
@@ -396,10 +413,10 @@ class DomaPanDAWork(Work):
             in_files.append(job['name'])
 
         task_param_map = {}
-        task_param_map['vo'] = 'wlcg'
-        if self.queue and len(self.queue) > 0:
-            task_param_map['site'] = self.queue
-        task_param_map['workingGroup'] = 'lsst'
+        task_param_map['vo'] = self.vo
+        if self.task_queue and len(self.task_queue) > 0:
+            task_param_map['site'] = self.task_queue
+        task_param_map['workingGroup'] = self.working_group
         task_param_map['nFilesPerJob'] = 1
         task_param_map['nFiles'] = len(in_files)
         task_param_map['noInput'] = True
